@@ -33,7 +33,7 @@ package Apache2::AMFLiteDetectionFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "4.32";;;
+  $VERSION= "4.33";
   my $CommonLib = new Apache2::AMFCommonLib ();
   my %MobileArray;#=$CommonLib->getMobileArray;
   my %MobileTabletArray;
@@ -49,17 +49,17 @@ package Apache2::AMFLiteDetectionFilter;
   my $configTVFile;
   my $checkVersion='true';
   my $mobilenable="false";
-  my $hostNames = "sourceforge.net";
+  my $hostNames = "github.com";
   my @hostName = split(/,/, $hostNames);
   my $numberOfAvaiableHosts=@hostName;
   my $correctHost=0;
   my $correctHostName=$hostName[$correctHost];
-  my $hostServer="http://".$correctHostName."/projects/mobilefilter/files/AMFRepository/";
-  my $urlmobile=$hostServer."litemobiledetection.config/download";
-  my $urlTablet=$hostServer."litetabletdetection.config/download";
-  my $urlTouch=$hostServer."litetouchdetection.config/download";
-  my $urlTv=$hostServer."litetvdetection.config/download";
-  my $urlBot=$hostServer."litebotdetection.config/download";
+  my $hostServer="https://".$correctHostName."/ifuschini/amf/blob/master/repository/";
+  my $urlmobile=$hostServer."litemobiledetection.config";
+  my $urlTablet=$hostServer."litetabletdetection.config";
+  my $urlTouch=$hostServer."litetouchdetection.config";
+  my $urlTv=$hostServer."litetvdetection.config";
+  my $urlBot=$hostServer."litebotdetection.config";
   my $forceBlockDownload="false";
   my $ua=LWP::UserAgent->new;
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
